The tavutil package provides a collection of utility Python modules:

* ``tavutil.async``
* ``tavutil.crypto``
* ``tavutil.daemon``
* ``tavutil.darwinsandbox``
* ``tavutil.dict``
* ``tavutil.env``
* ``tavutil.exception``
* ``tavutil.io``
* ``tavutil.ip``
* ``tavutil.jsonp``
* ``tavutil.lzf``
* ``tavutil.optcomplete``
* ``tavutil.optimise``
* ``tavutil.paypalx``
* ``tavutil.redis``
* ``tavutil.sanitise``
* ``tavutil.scm``
* ``tavutil.validation``
* ``tavutil.zeroconf``

**Contribute**

To contribute any patches simply fork the repository using GitHub and send a
pull request to https://github.com/tav, thanks!

**License**

All of the code, except where otherwise noted in file headers, has been released
into the `Public Domain <https://github.com/tav/tavutil/raw/master/UNLICENSE>`_.

-- 
Enjoy, tav <tav@espians.com>
